@@ -18,7 +18,7 @@
 from collections import defaultdict
 #from sixs_exceptions import *
 from Py6S.sixs_exceptions import ParameterError
-
+import sys
 
 class AeroProfile:
 
@@ -42,7 +42,7 @@ class AeroProfile:
 
         Example usage::
 
-          s.aeroprofile = AeroProfile.PredefinedType(AeroProfile.Urban)
+          s.aero_profile = AeroProfile.PredefinedType(AeroProfile.Urban)
 
         """
         return "%d" % type
@@ -64,8 +64,8 @@ class AeroProfile:
 
         Example usage::
 
-          s.aeroprofile = AeroProfile.User(dust=0.3, oceanic=0.7)
-          s.aeroprofile = AeroProfile.User(soot = 0.1, water = 0.3, oceanic = 0.05, dust = 0.55)
+          s.aero_profile = AeroProfile.User(dust=0.3, oceanic=0.7)
+          s.aero_profile = AeroProfile.User(soot = 0.1, water = 0.3, oceanic = 0.05, dust = 0.55)
 
         """
         d = defaultdict(lambda: 0, kwargs)
@@ -94,8 +94,8 @@ class AeroProfile:
 
         Example usage::
 
-          s.aeroprofile = AeroProfile.MultimodalLogNormalDistribution(0.3, 0.1)
-          s.aeroprofile.add_component(...)
+          s.aero_profile = AeroProfile.MultimodalLogNormalDistribution(0.1, 0.3)
+          s.aero_profile.add_component(...)
 
         """
         return cls.AerosolDistribution(rmin, rmax, 8)
@@ -114,8 +114,8 @@ class AeroProfile:
 
         Example usage::
 
-          s.aeroprofile = AeroProfile.ModifiedGammaDistribution(0.3, 0.1)
-          s.aeroprofile.add_component(...)
+          s.aero_profile = AeroProfile.ModifiedGammaDistribution(0.1, 0.3)
+          s.aero_profile.add_component(...)
 
         """
         return cls.AerosolDistribution(rmin, rmax, 9)
@@ -134,8 +134,8 @@ class AeroProfile:
 
         Example usage::
 
-          s.aeroprofile = AeroProfile.JungePowerLawDistribution(0.1, 0.3)
-          s.aeroprofile.add_component(...)
+          s.aero_profile = AeroProfile.JungePowerLawDistribution(0.1, 0.3)
+          s.aero_profile.add_component(...)
 
         """
         return cls.AerosolDistribution(rmin, rmax, 10)
@@ -191,6 +191,11 @@ class AeroProfile:
 
         real = map(str, refr_real)
         imag = map(str, refr_imag)
+
+        if sys.version_info[0] >= 3:
+            real = list(real)
+            imag = list(imag)
+
         comp += ' '.join(real) + '\n'
         comp += ' '.join(imag) + '\n'
 
@@ -207,10 +212,6 @@ class AeroProfile:
         * :meth:`.JungePowerLawDistribution`
 
         """
-        numtype = 0
-        rmin = 0
-        rmax = 0
-        values = []
 
         def __init__(self, rmin, rmax, numtype):
             """Initialise an Aerosol Distribution with various parameters.
@@ -227,6 +228,7 @@ class AeroProfile:
             self.rmin = rmin
             self.rmax = rmax
             self.numtype = numtype
+            self.values = []
 
         def add_component(self, rmean, sigma, percentage_density, refr_real, refr_imag):
             """Adds a component to the aerosol distribution.
@@ -257,6 +259,11 @@ class AeroProfile:
             comp = "%f %f %f\n" % (rmean, sigma, percentage_density)
             real = map(str, refr_real)
             imag = map(str, refr_imag)
+
+            if sys.version_info[0] >= 3:
+                real = list(real)
+                imag = list(imag)
+
             comp += ' '.join(real) + '\n'
             comp += ' '.join(imag) + '\n'
 
@@ -281,14 +288,12 @@ class AeroProfile:
 
         Example usage::
 
-          s.aeroprofile = AeroProfile.UserProfile(AeroProfile.Maritime)
-          s.aeroprofile.add_layer(5, 0.34) # Add a 5km-thick layer with an AOT of 0.34
-          s.aeroprofile.add_layer(10, 0.7) # Add a 10km-thick layer with an AOT of 0.7
-          s.aeroprofile.add_layer(100, 0.01) # Add a 100km-thick layer with an AOT of 0.01
+          s.aero_profile = AeroProfile.UserProfile(AeroProfile.Maritime)
+          s.aero_profile.add_layer(5, 0.34) # Add a 5km-thick layer with an AOT of 0.34
+          s.aero_profile.add_layer(10, 0.7) # Add a 10km-thick layer with an AOT of 0.7
+          s.aero_profile.add_layer(100, 0.01) # Add a 100km-thick layer with an AOT of 0.01
 
         """
-        values = []
-        aerotype = 0
 
         def __init__(self, atype):
             """Initialises the user-defined aerosol profile to a specific aerosol type.
@@ -299,6 +304,7 @@ class AeroProfile:
 
             """
             self.aerotype = atype
+            self.values = []
 
         def add_layer(self, height, optical_thickness):
             """Adds a layer to the user-defined profile.
@@ -310,7 +316,7 @@ class AeroProfile:
 
             Example usage::
 
-              s.aeroprofile.add_layer(5, 0.34) # Add a 5km-thick layer with an AOT of 0.34
+              s.aero_profile.add_layer(5, 0.34) # Add a 5km-thick layer with an AOT of 0.34
             """
             self.values.append((height, optical_thickness))
 
