@@ -15,10 +15,27 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Py6S.  If not, see <http://www.gnu.org/licenses/>.
 
-import urllib2
-from StringIO import StringIO
+import sys
 import numpy as np
 
+# Python 2/3 imports
+try:
+    import urllib2
+except ImportError:
+    if sys.version_info[0] >= 3:
+        import urllib.request as urllib2
+    else:
+        raise
+
+try:
+    from StringIO import StringIO
+except ImportError:
+    if sys.version_info[0] >= 3:
+        from io import StringIO
+    else:
+        raise
+
+
 
 class Spectra:
 
@@ -53,7 +70,10 @@ class Spectra:
         """
         if loc.startswith("""http://"""):
             data = urllib2.urlopen(loc).read()
-            f = StringIO(data)
+            if sys.version_info[0] >= 3:
+                f = StringIO(data.decode())
+            else:
+                f = StringIO(data)
         else:
             f = open(loc, "r")
 
@@ -91,7 +111,10 @@ class Spectra:
         """
         if loc.startswith("""http://"""):
             data = urllib2.urlopen(loc).read()
-            f = StringIO(data)
+            if sys.version_info[0] >= 3:
+                f = StringIO(data.decode())
+            else:
+                f = StringIO(data)
         else:
             f = open(loc, "r")
 
