@@ -17,6 +17,7 @@
 
 import subprocess
 import os
+import sys
 import numpy as np
 from scipy.interpolate import interp1d
 from .Params import *
@@ -26,6 +27,12 @@ import tempfile
 import math
 
 
+SIXSVERSION = '1.1'
+
+# Fix for Python 3 where basestring is not available
+if sys.version_info[0] >= 3:
+    basestring = str
+
 class SixS(object):
 
     """Wrapper for the 6S Radiative Transfer Model.
@@ -77,6 +84,21 @@ class SixS(object):
 
                             s.atmos_corr = AtmosCorr.AtmosCorrLambertianFromReflectance(0.23)
 
+    * ``aot550`` -- The Aerosol Optical Thickness value (measured at 550nm) to use for the simulation. For example ::
+                            
+                            s.aot550 = 0.2
+                    
+      Note: only one of ``visibility`` or ``aot550`` can be set.
+      When setting one, ensure the other is set to ``None``. (By default, ``s.visibility`` is set to None,
+      so just setting ``s.aot550`` will work.)
+
+    * ``visibility`` -- The visibility value (in km) to use for the simulation. For example::
+
+                            s.visibility = 40
+
+      Note: only one of ``visibility`` or ``aot550`` can be set.
+      When setting one, ensure the other is set to ``None``. (By default, ``s.visibility`` is set to None,
+      so to set a visibility value you must also do ``s.aot550 = None``)
     """
 
     # Stores the outputs from 6S as an instance of the Outputs class
@@ -85,7 +107,7 @@ class SixS(object):
     min_wv = None
     max_wv = None
 
-    __version__ = "1.5.4"
+    __version__ = "1.8.1"
 
     def __init__(self, path=None):
         """Initialises the class and finds the right 6S executable to use.
@@ -259,14 +281,14 @@ class SixS(object):
         # we need to interpolate to the right spacing
         # and replace the REFL_REPLACE bit of the string
 
-        if "REFL_REPLACE" in str_ground_refl:
-            new_str = self._refls_to_string(ground_reflectance_lines[1])
-            str_ground_refl = str_ground_refl.replace("REFL_REPLACE", new_str)
-
         if "REFL_REPLACE_2" in str_ground_refl:
             new_str = self._refls_to_string(ground_reflectance_lines[2])
             str_ground_refl = str_ground_refl.replace("REFL_REPLACE_2", new_str)
 
+        if "REFL_REPLACE" in str_ground_refl:
+            new_str = self._refls_to_string(ground_reflectance_lines[1])
+            str_ground_refl = str_ground_refl.replace("REFL_REPLACE", new_str)
+
         input_file += str_ground_refl
 
         input_file += self._create_atmos_corr_lines()
@@ -276,7 +298,11 @@ class SixS(object):
             # No filename given, so write to temporary file
             tmp_file = tempfile.NamedTemporaryFile(prefix="tmp_Py6S_input_", delete=False)
 
-            tmp_file.file.write(input_file)
+            # For Python 3, convert to Byte
+            if sys.version_info[0] >= 3:
+                tmp_file.file.write(bytes(input_file,'utf-8'))
+            else:
+                tmp_file.file.write(input_file)
             name = tmp_file.name
             tmp_file.close()
         else:
@@ -313,39 +339,41 @@ class SixS(object):
         import platform
         import sys
 
-        print "Py6S Debugging Report"
-        print "---------------------"
-        print "Run on %s" % (str(datetime.datetime.now()))
-        print "Platform: %s" % (platform.platform())
-        print "Python version: %s" % (sys.version.split('\n')[0])
-        print "Py6S version: %s" % (self.__version__)
-        print "---------------------"
+        print("Py6S Debugging Report")
+        print("---------------------")
+        print("Run on %s" % (str(datetime.datetime.now())))
+        print("Platform: %s" % (platform.platform()))
+        print("Python version: %s" % (sys.version.split('\n')[0]))
+        print("Py6S version: %s" % (self.__version__))
+        print("---------------------")
         self.test()
-        print "---------------------"
+        print("---------------------")
 
         fname = self.write_input_file()
         with open(fname) as f:
             contents = f.readlines()
 
-        print "".join(contents)
+        print("".join(contents))
 
     @classmethod
-    def test(self):
+    def test(cls, path=None):
         """Runs a simple test to ensure that 6S and Py6S are installed correctly."""
-        test = SixS()
-        print "6S wrapper script by Robin Wilson"
-        sixs_path = test._find_path()
+        test = cls(path)
+        print("6S wrapper script by Robin Wilson")
+        sixs_path = test._find_path(path)
         if sixs_path is None:
-            print "Error: cannot find the sixs executable in $PATH or current directory."
+            print("Error: cannot find the sixs executable in $PATH or current directory.")
         else:
-            print "Using 6S located at %s" % sixs_path
-            print "Running 6S using a set of test parameters"
+            print("Using 6S located at %s" % sixs_path)
+            print("Running 6S using a set of test parameters")
             test.run()
-            print "The results are:"
-            print "Expected result: %f" % 619.158
-            print "Actual result: %f" % test.outputs.diffuse_solar_irradiance
-            if (test.outputs.diffuse_solar_irradiance - 619.158 < 0.01):
-                print "#### Results agree, Py6S is working correctly"
+            print("6sV version: %s" % (test.outputs.version))
+            assert test.outputs.version == SIXSVERSION, "Unsupported 6sV version: {0}. Need version {1}".format(test.outputs.version, SIXSVERSION)
+            print("The results are:")
+            print("Expected result: %f" % 619.158)
+            print("Actual result: %f" % test.outputs.diffuse_solar_irradiance)
+            if np.abs((test.outputs.diffuse_solar_irradiance - 619.158) < 0.01):
+                print("#### Results agree, Py6S is working correctly")
                 return 0
             else:
                 return 1
